@@ -59,12 +59,14 @@ analyze.glmerMod <- function(x, ...) {
   values$R2c <- R2c
 
   # Loop over all variables
-  for (varname in varnames){
-    text <- paste("The effect of ", varname, " was [NOT] significant (beta = ",
-                  format_digit(fitsum[varname, "Coef"], 2), ", SE = ",
-                  format_digit(fitsum[varname, "SE"], 2), ", z = ",
-                  format_digit(fitsum[varname, "z"], 2), ", p ",
-                  format_p(fitsum[varname, "p"]), ").", sep = "")
+  for (varname in varnames) {
+    text <- paste(
+      "The effect of ", varname, " was [NOT] significant (beta = ",
+      format_digit(fitsum[varname, "Coef"], 2), ", SE = ",
+      format_digit(fitsum[varname, "SE"], 2), ", z = ",
+      format_digit(fitsum[varname, "z"], 2), ", p ",
+      format_p(fitsum[varname, "p"]), ").", sep = ""
+    )
 
     values[[varname]] <- list(
       Coef = fitsum[varname, "Coef"],
@@ -79,16 +81,18 @@ analyze.glmerMod <- function(x, ...) {
 
   # Text
   # -------------
-  text <- c(paste("The overall model predicting ... successfully converged ",
-                  "and explained ",
-                  format_digit(R2c * 100, 2), "% of the variance of the",
-                  " endogen (the conditional R2). ",
-                  "The variance explained by the fixed effects was of ",
-                  format_digit(R2m * 100, 2), "% (the marginal R2) and the ",
-                  "one explained by the random effects of ",
-                  format_digit((R2c - R2m) * 100, 2), "%.", sep = ""))
+  text <- c(paste(
+    "The overall model predicting ... successfully converged ",
+    "and explained ",
+    format_digit(R2c * 100, 2), "% of the variance of the",
+    " endogen (the conditional R2). ",
+    "The variance explained by the fixed effects was of ",
+    format_digit(R2m * 100, 2), "% (the marginal R2) and the ",
+    "one explained by the random effects of ",
+    format_digit((R2c - R2m) * 100, 2), "%.", sep = ""
+  ))
 
-  for (varname in varnames){
+  for (varname in varnames) {
     text <- c(text, values[[varname]]$Text)
   }
 
